==> kubernetes-model-flowcontrol-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PriorityLevelConfigurationFluentImpl<A extends PriorityLevelConfigurationFluent<A>> extends BaseFluent<A> implements PriorityLevelConfigurationFluent<A>{
  public PriorityLevelConfigurationFluentImpl() {
  }
  public PriorityLevelConfigurationFluentImpl(PriorityLevelConfiguration instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PriorityLevelConfigurationSpecBuilder spec;
  private PriorityLevelConfigurationStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PriorityLevelConfigurationFluent.MetadataNested<A> withNewMetadata() {
    return new PriorityLevelConfigurationFluentImpl.MetadataNestedImpl();
  }
  public PriorityLevelConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PriorityLevelConfigurationFluentImpl.MetadataNestedImpl(item);
  }
  public PriorityLevelConfigurationFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PriorityLevelConfigurationFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PriorityLevelConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PriorityLevelConfigurationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PriorityLevelConfigurationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PriorityLevelConfigurationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PriorityLevelConfigurationFluent.SpecNested<A> withNewSpec() {
    return new PriorityLevelConfigurationFluentImpl.SpecNestedImpl();
  }
  public PriorityLevelConfigurationFluent.SpecNested<A> withNewSpecLike(PriorityLevelConfigurationSpec item) {
    return new PriorityLevelConfigurationFluentImpl.SpecNestedImpl(item);
  }
  public PriorityLevelConfigurationFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PriorityLevelConfigurationFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PriorityLevelConfigurationSpecBuilder().build());
  }
  public PriorityLevelConfigurationFluent.SpecNested<A> editOrNewSpecLike(PriorityLevelConfigurationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PriorityLevelConfigurationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PriorityLevelConfigurationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PriorityLevelConfigurationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PriorityLevelConfigurationFluent.StatusNested<A> withNewStatus() {
    return new PriorityLevelConfigurationFluentImpl.StatusNestedImpl();
  }
  public PriorityLevelConfigurationFluent.StatusNested<A> withNewStatusLike(PriorityLevelConfigurationStatus item) {
    return new PriorityLevelConfigurationFluentImpl.StatusNestedImpl(item);
  }
  public PriorityLevelConfigurationFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PriorityLevelConfigurationFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PriorityLevelConfigurationStatusBuilder().build());
  }
  public PriorityLevelConfigurationFluent.StatusNested<A> editOrNewStatusLike(PriorityLevelConfigurationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PriorityLevelConfigurationFluentImpl that = (PriorityLevelConfigurationFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PriorityLevelConfigurationFluent.MetadataNested<N>> implements PriorityLevelConfigurationFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PriorityLevelConfigurationSpecFluentImpl<PriorityLevelConfigurationFluent.SpecNested<N>> implements PriorityLevelConfigurationFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PriorityLevelConfigurationSpec item) {
      this.builder = new PriorityLevelConfigurationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PriorityLevelConfigurationSpecBuilder(this);
    }
    PriorityLevelConfigurationSpecBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PriorityLevelConfigurationStatusFluentImpl<PriorityLevelConfigurationFluent.StatusNested<N>> implements PriorityLevelConfigurationFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PriorityLevelConfigurationStatus item) {
      this.builder = new PriorityLevelConfigurationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PriorityLevelConfigurationStatusBuilder(this);
    }
    PriorityLevelConfigurationStatusBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PriorityLevelConfigurationFluentImpl<A extends PriorityLevelConfigurationFluent<A>> extends BaseFluent<A> implements PriorityLevelConfigurationFluent<A>{
  public PriorityLevelConfigurationFluentImpl() {
  }
  public PriorityLevelConfigurationFluentImpl(PriorityLevelConfiguration instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PriorityLevelConfigurationSpecBuilder spec;
  private PriorityLevelConfigurationStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PriorityLevelConfigurationFluentImpl.MetadataNested<A> withNewMetadata() {
    return new PriorityLevelConfigurationFluentImpl.MetadataNestedImpl();
  }
  public PriorityLevelConfigurationFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PriorityLevelConfigurationFluentImpl.MetadataNestedImpl(item);
  }
  public PriorityLevelConfigurationFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PriorityLevelConfigurationFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PriorityLevelConfigurationFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PriorityLevelConfigurationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PriorityLevelConfigurationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PriorityLevelConfigurationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PriorityLevelConfigurationFluentImpl.SpecNested<A> withNewSpec() {
    return new PriorityLevelConfigurationFluentImpl.SpecNestedImpl();
  }
  public PriorityLevelConfigurationFluentImpl.SpecNested<A> withNewSpecLike(PriorityLevelConfigurationSpec item) {
    return new PriorityLevelConfigurationFluentImpl.SpecNestedImpl(item);
  }
  public PriorityLevelConfigurationFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PriorityLevelConfigurationFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PriorityLevelConfigurationSpecBuilder().build());
  }
  public PriorityLevelConfigurationFluentImpl.SpecNested<A> editOrNewSpecLike(PriorityLevelConfigurationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PriorityLevelConfigurationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PriorityLevelConfigurationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PriorityLevelConfigurationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PriorityLevelConfigurationFluentImpl.StatusNested<A> withNewStatus() {
    return new PriorityLevelConfigurationFluentImpl.StatusNestedImpl();
  }
  public PriorityLevelConfigurationFluentImpl.StatusNested<A> withNewStatusLike(PriorityLevelConfigurationStatus item) {
    return new PriorityLevelConfigurationFluentImpl.StatusNestedImpl(item);
  }
  public PriorityLevelConfigurationFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PriorityLevelConfigurationFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PriorityLevelConfigurationStatusBuilder().build());
  }
  public PriorityLevelConfigurationFluentImpl.StatusNested<A> editOrNewStatusLike(PriorityLevelConfigurationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PriorityLevelConfigurationFluentImpl that = (PriorityLevelConfigurationFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PriorityLevelConfigurationFluentImpl.MetadataNested<N>> implements PriorityLevelConfigurationFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PriorityLevelConfigurationSpecFluentImpl<PriorityLevelConfigurationFluentImpl.SpecNested<N>> implements PriorityLevelConfigurationFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PriorityLevelConfigurationSpec item) {
      this.builder = new PriorityLevelConfigurationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PriorityLevelConfigurationSpecBuilder(this);
    }
    PriorityLevelConfigurationSpecBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PriorityLevelConfigurationStatusFluentImpl<PriorityLevelConfigurationFluentImpl.StatusNested<N>> implements PriorityLevelConfigurationFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PriorityLevelConfigurationStatus item) {
      this.builder = new PriorityLevelConfigurationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PriorityLevelConfigurationStatusBuilder(this);
    }
    PriorityLevelConfigurationStatusBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
